package handler

import (
	"cicv-data-closedloop/amd64/score_server/dao/mapper"
	"cicv-data-closedloop/common/config/c_log"
	commonEntity "cicv-data-closedloop/common/entity"
	"github.com/gin-gonic/gin"
	"net/http"
	"sync"
)

type CollectLimitPao struct {
	SnCode            string ` json:"snCode"`            // 机器人sn码
	CollectLimitDay   string ` json:"collectLimitDay"`   // 机器人配置的每日限额采集数
	CollectLimitWeek  string ` json:"collectLimitWeek"`  // 机器人配置的每周限额采集数
	CollectLimitMonth string ` json:"collectLimitMonth"` // 机器人配置的每月限额采集数
	CollectLimitYear  string ` json:"collectLimitYear"`  // 机器人配置的每年限额采集数
}

var globalMutex sync.Mutex

// 接收设备数据采集触发信号，判断是否允许设备继续采集，如果允许返回允许信号（code为200），否则为拒绝采集
func TriggerCollect(c *gin.Context) {
	globalMutex.Lock()
	defer globalMutex.Unlock()
	param := new(CollectLimitPao)
	// 映射到结构体
	if err := c.ShouldBindJSON(&param); err != nil {
		c_log.GlobalLogger.Error("项目启动接收请求参数报错：", err)
		c.JSON(http.StatusBadRequest, commonEntity.Response{Code: 500, Msg: "请求体解析失败。"})
		return
	}
	// 1 根据sn码查询当前设备已采集的包数量
	collectLimitPo := mapper.SelectFromCollectLimitBySnCode(param.SnCode)
	// 2 将查出的数据与参数中的限额数进行对比，判断是否允许采集，如果允许，则返回 code 200
	if collectLimitPo.YearCollectedNumber < param.CollectLimitYear {
		if collectLimitPo.MonthCollectedNumber < param.CollectLimitMonth {
			if collectLimitPo.WeekCollectedNumber < param.CollectLimitWeek {
				if collectLimitPo.DayCollectedNumber < param.CollectLimitDay {
					// 所有值添加一
					mapper.UpdateCollectLimit(param.SnCode)
					// 返回允许信号
					c.JSON(http.StatusOK, commonEntity.Response{
						Code: 200,
						Msg:  "允许采集。",
					})
					return
				}
			}
		}
	}
	c.JSON(http.StatusOK, commonEntity.Response{
		Code: 400,
		Msg:  "不允许采集。",
	})
}
